@@ -8,12 +8,13 @@ import (
 )
 
 var (
-	Version   = "unset"
-	Revision  = "unset"
-	Branch    = "unset"
-	BuildUser = "unset"
-	BuildDate = "unset"
-	GoVersion = runtime.Version()
+	Version   = "unset" // Version is set at build time
+	Revision  = "unset" // Revision is set at build time
+	Branch    = "unset" // Branch is set at build time
+	BuildUser = "unset" // BuildUser is set at build time
+	BuildDate = "unset" // BuildDate is set at build time
+
+	goVersion = runtime.Version()
 )
 
 var (
@@ -28,7 +29,7 @@ var (
 
 func init() {
 	prometheus.MustRegister(buildInfo)
-	buildInfo.WithLabelValues(Version, Revision, Branch, GoVersion).Set(1)
+	buildInfo.WithLabelValues(Version, Revision, Branch, goVersion).Set(1)
 }
 
 func versionStr() string {
